@@ -34,6 +34,7 @@
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <kprocess.h>
+#include <kprocio.h>
 #include <kpassdlg.h>
 
 // ark includes
@@ -50,18 +51,66 @@ ZipArch::ZipArch( ArkWidget *_gui, const TQString & _fileName )
   verifyCompressUtilityIsAvailable( m_archiver_program );
   verifyUncompressUtilityIsAvailable( m_unarchiver_program );
 
+  // Compatibility with unzip v5 and v6.
+  //  - unzip 5 prints dates as MM-DD-YY.
+  //  - unzip 6 prints dates as YYYY-MM-DD.
+  // Presume version 6 as it was released in 2009.
+  bool unzipV5 = false;
+  if (m_bUnarchUtilityIsAvailable)
+  {
+    KProcIO proc;
+    proc << m_unarchiver_program;
+    proc << "-v";
+    if (proc.start(KProcIO::Block))
+    {
+      proc.wait();
+      if (proc.normalExit() && proc.exitStatus() == 0)
+      {
+        TQString line;
+        proc.readln(line);
+        auto parts = TQStringList::split(' ', line);
+        unzipV5 = (parts.size() >= 2) && (parts[1][0] == '5');
+      }
+    }
+  }
+
   m_headerString = "----";
-  m_repairYear = 9; m_fixMonth = 7; m_fixDay = 8; m_fixTime = 10;
+  m_fixTime = 10;
   m_dateCol = 5;
   m_numCols = 7;
 
+  if (unzipV5)
+  {
+    kdDebug(1601) << "ZipArch: unzip v5 detected." << endl;
+    m_repairYear = 9;
+    m_fixMonth = 7;
+    m_fixDay = 8;
+  }
+  else
+  {
+    m_fixYear = 7;
+    m_fixMonth = 8;
+    m_fixDay = 9;
+  }
+
   m_archCols.append( new ArchColumns( 1, TQRegExp( "[0-9]+" ) ) );
   m_archCols.append( new ArchColumns( 2, TQRegExp( "[^\\s]+" ) ) );
   m_archCols.append( new ArchColumns( 3, TQRegExp( "[0-9]+" ) ) );
   m_archCols.append( new ArchColumns( 4, TQRegExp( "[0-9.]+%" ) ) );
-  m_archCols.append( new ArchColumns( 7, TQRegExp( "[01][0-9]" ), 2 ) );
-  m_archCols.append( new ArchColumns( 8, TQRegExp( "[0-3][0-9]" ), 2 ) );
-  m_archCols.append( new ArchColumns( 9, TQRegExp( "[0-9][0-9]" ), 2 ) );
+
+  if (unzipV5)
+  {
+    m_archCols.append( new ArchColumns( 7, TQRegExp( "[01][0-9]" ), 2 ) );
+    m_archCols.append( new ArchColumns( 8, TQRegExp( "[0-3][0-9]" ), 2 ) );
+    m_archCols.append( new ArchColumns( 9, TQRegExp( "[0-9][0-9]" ), 2 ) );
+  }
+  else
+  {
+    m_archCols.append( new ArchColumns( 7, TQRegExp( "[0-9]{4}" ), 4 ) );
+    m_archCols.append( new ArchColumns( 8, TQRegExp( "[01][0-9]" ), 2 ) );
+    m_archCols.append( new ArchColumns( 9, TQRegExp( "[0-3][0-9]" ), 2 ) );
+  }
+
   m_archCols.append( new ArchColumns( 10, TQRegExp( "[0-9:]+" ), 6 ) );
   m_archCols.append( new ArchColumns( 6, TQRegExp( "[a-fA-F0-9]+ {2}" ) ) );
   m_archCols.append( new ArchColumns( 0, TQRegExp( "[^\\n]+" ), 4096 ) );
@@ -94,12 +143,12 @@ void ZipArch::open()
 
   *kp << m_unarchiver_program << "-v" << m_filename;
 
-  connect( kp, TQT_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedTOC(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( processExited(TDEProcess*) ),
-           TQT_SLOT( slotOpenExited(TDEProcess*) ) );
+  connect( kp, TQ_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedTOC(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( processExited(TDEProcess*) ),
+           TQ_SLOT( slotOpenExited(TDEProcess*) ) );
 
   if ( !kp->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
   {
@@ -172,12 +221,12 @@ void ZipArch::addFile( const TQStringList &urls )
     *kp << fileURL.fileName();
   }
 
-  connect( kp, TQT_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( processExited(TDEProcess*) ),
-           TQT_SLOT( slotAddExited(TDEProcess*) ) );
+  connect( kp, TQ_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( processExited(TDEProcess*) ),
+           TQ_SLOT( slotAddExited(TDEProcess*) ) );
 
   if ( !kp->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
   {
@@ -231,12 +280,12 @@ void ZipArch::unarchFileInternal()
 
   *kp << "-d" << m_destDir;
 
-  connect( kp, TQT_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( processExited(TDEProcess*) ),
-           TQT_SLOT( slotExtractExited(TDEProcess*) ) );
+  connect( kp, TQ_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( processExited(TDEProcess*) ),
+           TQ_SLOT( slotExtractExited(TDEProcess*) ) );
 
   if ( !kp->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
   {
@@ -268,12 +317,12 @@ void ZipArch::remove( TQStringList *list )
     *kp << str;
   }
 
-  connect( kp, TQT_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
-           TQT_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, TQT_SIGNAL( processExited(TDEProcess*) ),
-           TQT_SLOT( slotDeleteExited(TDEProcess*) ) );
+  connect( kp, TQ_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( processExited(TDEProcess*) ),
+           TQ_SLOT( slotDeleteExited(TDEProcess*) ) );
 
   if ( !kp->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
   {
@@ -296,12 +345,12 @@ void ZipArch::test()
 
   *kp << m_filename;
 
-  connect( kp, SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
-           SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
-           SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
-  connect( kp, SIGNAL( processExited(TDEProcess*) ),
-           SLOT( slotTestExited(TDEProcess*) ) );
+  connect( kp, TQ_SIGNAL( receivedStdout(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( receivedStderr(TDEProcess*, char*, int) ),
+           TQ_SLOT( slotReceivedOutput(TDEProcess*, char*, int) ) );
+  connect( kp, TQ_SIGNAL( processExited(TDEProcess*) ),
+           TQ_SLOT( slotTestExited(TDEProcess*) ) );
 
   if ( !kp->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
   {
