@@ -37,7 +37,7 @@ class TDEActionCollection;
 
 class DispLogic : public KCalcDisplay
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
