@@ -124,7 +124,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                                             : "locationbar_erase"));
 	(void) new TQLabel(i18n("Search: "),hBar);
 	TDEListViewSearchLine* listViewSearch = new TDEListViewSearchLine(hBar);
-	connect(clearSearch, TQT_SIGNAL(pressed()), listViewSearch, TQT_SLOT(clear()));
+	connect(clearSearch, TQ_SIGNAL(pressed()), listViewSearch, TQ_SLOT(clear()));
 #endif
 
         keysList = new TDEListView( page );
@@ -147,10 +147,10 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 	keysList->setColumnWidth(0,210);
 	keysList->setColumnWidth(1,210);
 
-        boutonboxoptions=new TQButtonGroup(5,Qt::Vertical ,page,0);
+        boutonboxoptions=new TQButtonGroup(5,TQt::Vertical ,page,0);
 
 	TDEActionCollection *actcol=new TDEActionCollection(this);
-	(void) new TDEAction(i18n("&Go to Default Key"),goDefaultKey, TQT_TQOBJECT(this), TQT_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
+	(void) new TDEAction(i18n("&Go to Default Key"),goDefaultKey, this, TQ_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
 
 
         CBarmor=new TQCheckBox(i18n("ASCII armored encryption"),boutonboxoptions);
@@ -189,7 +189,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                 TQWhatsThis::add
                         (CBsymmetric,i18n("<b>Symmetrical encryption</b>: encryption does not use keys. You just need to give a password "
                                           "to encrypt/decrypt the file"));
-                TQObject::connect(CBsymmetric,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(isSymetric(bool)));
+                TQObject::connect(CBsymmetric,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(isSymetric(bool)));
 
 	CBarmor->setChecked( KGpgSettings::asciiArmor() );
 	CBuntrusted->setChecked( KGpgSettings::allowUntrustedKeys() );
@@ -204,11 +204,11 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                 optiontxt->setText(customOptions);
                 TQWhatsThis::add
                         (optiontxt,i18n("<b>Custom option</b>: for experienced users only, allows you to enter a gpg command line option, like: '--armor'"));
-                TQObject::connect(optiontxt,TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(customOpts(const TQString & )));
+                TQObject::connect(optiontxt,TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(customOpts(const TQString & )));
         }
-        TQObject::connect(keysList,TQT_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(slotOk()));
-//	TQObject::connect(this,TQT_SIGNAL(okClicked()),this,TQT_SLOT(crypte()));
-        TQObject::connect(CBuntrusted,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(refresh(bool)));
+        TQObject::connect(keysList,TQ_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(slotOk()));
+//	TQObject::connect(this,TQ_SIGNAL(okClicked()),this,TQ_SLOT(crypte()));
+        TQObject::connect(CBuntrusted,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(refresh(bool)));
 
         char line[200]="\0";
         FILE *fp2;
@@ -343,26 +343,111 @@ void popupPublic::refreshkeys()
         KProcIO *encid=new KProcIO(TQTextCodec::codecForLocale());
         *encid << "gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--with-colon"<<"--list-keys";
         /////////  when process ends, update dialog infos
-        TQObject::connect(encid, TQT_SIGNAL(processExited(TDEProcess *)),this, TQT_SLOT(slotpreselect()));
-        TQObject::connect(encid, TQT_SIGNAL(readReady(KProcIO *)),this, TQT_SLOT(slotprocread(KProcIO *)));
+        TQObject::connect(encid, TQ_SIGNAL(processExited(TDEProcess *)),this, TQ_SLOT(slotpreselect()));
+        TQObject::connect(encid, TQ_SIGNAL(readReady(KProcIO *)),this, TQ_SLOT(slotprocread(KProcIO *)));
         encid->start(TDEProcess::NotifyOnExit,true);
 }
 
 void popupPublic::slotpreselect()
 {
-TQListViewItem *it=NULL;
-if (!keysList->firstChild()) return;
-        if (fmode) it=keysList->findItem(KGpgSettings::defaultKey(),2);
-if (!trusted)
-              sort();
-if (fmode)
-{
-  	keysList->clearSelection();
-	keysList->setSelected(it,true);
-	keysList->setCurrentItem(it);
-	keysList->ensureItemVisible(it);
-}
-emit keyListFilled();
+
+    TQString defaultKey = KGpgSettings::defaultKey().right(8);
+
+    // process the output to update dialog infos
+    TQMap<TQString,TQStringList>::Iterator ite;
+    for (ite = hashMap.begin(); ite != hashMap.end(); ite++) {
+        TQStringList::Iterator it;
+        TQString fullname,keyname,keymail,val,id;
+        bool dead;
+        for (it = ite.data().begin(); it != ite.data().end(); it++) {
+            TQString line =  (*it);
+            kdDebug(2100) << k_funcinfo << line << endl;
+
+            if (line.startsWith("pub")) {
+                TQStringList keyString=TQStringList::split(":",line,true);
+                dead=false;
+                const TQString trust=keyString[1];
+                val=keyString[6];
+                id=TQString("0x"+keyString[4].right(8));
+                if (val.isEmpty()) {
+                    val=i18n("Unlimited");
+                }
+// unused       TQString tr;
+                switch( trust[0] ) {
+                    case 'o':   // unknown
+                        untrustedList<<id;  // untrustedList used in sort
+                        break;
+                    case 'i':   // invalid
+                    case 'd':   // disabled
+                    case 'r':   // revoked
+                    case 'e':   // expired
+                        dead=true;
+                        break;
+                    case 'q':   // undefined
+                    case 'n':   // none
+                    case 'm':   // marginal
+                        untrustedList<<id;
+                        break;
+                    case 'f':   // full
+                    case 'u':   // ultimate
+                        break;
+                    default:
+                        untrustedList<<id;
+                        break;
+                }
+                if (keyString[11].find('D')!=-1) {  // disabled
+                    dead=true;
+                }
+                fullname=keyString[9];
+            }
+
+            if ( line.startsWith("uid") && fullname.isEmpty() ) {
+                fullname = line.section(':',9,9);
+            }
+        }
+
+        if (fullname.find("<")!=-1) {
+            keymail=fullname.section('<',-1,-1);
+            keymail.truncate(keymail.length()-1);
+            keyname=fullname.section('<',0,0);
+            //if (keyname.find("(")!=-1) {
+            //  keyname=keyname.section('(',0,0);
+            //}
+        }
+        else {
+            keymail=TQString();
+            keyname=fullname;//.section('(',0,0);
+        }
+        if ((!dead) && (!fullname.isEmpty())) {
+            bool isDefaultKey=false;
+            if (id.right(8)==defaultKey) {
+                isDefaultKey=true;
+            }
+            UpdateViewItem2 *item=new UpdateViewItem2(keysList,keyname,keymail,id,isDefaultKey);
+            //TDEListViewItem *sub= new TDEListViewItem(item,i18n("ID: %1, trust: %2, validity: %3").arg(id).arg(tr).arg(val));
+            //sub->setSelectable(false);
+            if (seclist.find(fullname,0,FALSE)!=-1) {
+                item->setPixmap(0,keyPair);
+            }
+            else {
+                item->setPixmap(0,keySingle);
+            }
+        }
+    }
+    //
+    TQListViewItem *it=NULL;
+    if (!keysList->firstChild()) return;
+            if (fmode) it=keysList->findItem(KGpgSettings::defaultKey(),2);
+    if (!trusted)
+                  sort();
+    if (fmode)
+    {
+        keysList->clearSelection();
+        keysList->setSelected(it,true);
+        keysList->setCurrentItem(it);
+        keysList->ensureItemVisible(it);
+    }
+    emit keyListFilled();
 }
 
 void popupPublic::slotSetVisible()
@@ -372,14 +457,11 @@ void popupPublic::slotSetVisible()
 
 void popupPublic::slotprocread(KProcIO *p)
 {
+//  collect all data (output starts with pub line followed by related)
 //	kdDebug(2100) << k_funcinfo << endl;
-        ///////////////////////////////////////////////////////////////// extract  encryption keys
 	TQString tst;
 
-        TQString defaultKey = KGpgSettings::defaultKey().right(8);
-
 	while (p->readln(tst)!=-1) {
-//		kdDebug(2100) << k_funcinfo << "Read one public key line: " << tst << endl;
 		if ( tst.startsWith("pub")  ) {
 			currentKey = tst.section(':',4,4);
 			TQStringList lst; lst << tst;
@@ -389,98 +471,6 @@ void popupPublic::slotprocread(KProcIO *p)
 			hashMap.find(currentKey).data().append(tst);
 		}
 	}
-
-	TQMap<TQString,TQStringList>::Iterator ite;
-	for (ite = hashMap.begin(); ite != hashMap.end(); ite++) {
-		TQStringList::Iterator it;
-		TQString fullname,keyname,keymail,val,id;
-		bool dead;
-
-		for (it = ite.data().begin(); it != ite.data().end(); it++) {
-			TQString line =  (*it);
-
-			if (line.startsWith("pub")) {
-				TQStringList keyString=TQStringList::split(":",line,true);
-				dead=false;
-				const TQString trust=keyString[1];
-				val=keyString[6];
-				id=TQString("0x"+keyString[4].right(8));
-				if (val.isEmpty()) {
-					val=i18n("Unlimited");
-				}
-				TQString tr;
-				switch( trust[0] ) {
-					case 'o':
-						untrustedList<<id;
-						break;
-					case 'i':
-						dead=true;
-						break;
-					case 'd':
-						dead=true;
-						break;
-					case 'r':
-						dead=true;
-						break;
-					case 'e':
-						dead=true;
-						break;
-					case 'q':
-						untrustedList<<id;
-						break;
-					case 'n':
-						untrustedList<<id;
-						break;
-					case 'm':
-						untrustedList<<id;
-						break;
-					case 'f':
-						break;
-					case 'u':
-						break;
-					default:
-						untrustedList<<id;
-						break;
-				}
-				if (keyString[11].find('D')!=-1) {
-					dead=true;
-				}
-				fullname=keyString[9];
-			}
-
-			if ( line.startsWith("uid") && fullname.isEmpty() ) {
-				fullname = line.section(':',9,9);
-			}
-		}
-
-		if (fullname.find("<")!=-1) {
-			keymail=fullname.section('<',-1,-1);
-			keymail.truncate(keymail.length()-1);
-			keyname=fullname.section('<',0,0);
-			//if (keyname.find("(")!=-1) {
-			//	keyname=keyname.section('(',0,0);
-			//}
-		}
-		else {
-			keymail=TQString();
-			keyname=fullname;//.section('(',0,0);
-		}
-		if ((!dead) && (!fullname.isEmpty())) {
-			bool isDefaultKey=false;
-			if (id.right(8)==defaultKey) {
-				isDefaultKey=true;
-			}
-			UpdateViewItem2 *item=new UpdateViewItem2(keysList,keyname,keymail,id,isDefaultKey);
-			//TDEListViewItem *sub= new TDEListViewItem(item,i18n("ID: %1, trust: %2, validity: %3").arg(id).arg(tr).arg(val));
-			//sub->setSelectable(false);
-			if (seclist.find(fullname,0,FALSE)!=-1) {
-				item->setPixmap(0,keyPair);
-			}
-			else {
-				item->setPixmap(0,keySingle);
-			}
-		}
-	}
 }
 
 
