@@ -138,9 +138,9 @@ KHexEdit::KHexEdit( KDataBuffer *Buffer, TQWidget *Parent, const char *Name, WFl
   viewport()->installEventFilter( this );
   installEventFilter( this );
 
-  connect( CursorBlinkTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(blinkCursor()) );
-  connect( ScrollTimer,      TQT_SIGNAL(timeout()), this, TQT_SLOT(autoScrollTimerDone()) );
-  connect( DragStartTimer,   TQT_SIGNAL(timeout()), this, TQT_SLOT(startDrag()) );
+  connect( CursorBlinkTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(blinkCursor()) );
+  connect( ScrollTimer,      TQ_SIGNAL(timeout()), this, TQ_SLOT(autoScrollTimerDone()) );
+  connect( DragStartTimer,   TQ_SIGNAL(timeout()), this, TQ_SLOT(startDrag()) );
 
   viewport()->setAcceptDrops( true );
 }
@@ -1042,7 +1042,7 @@ void KHexEdit::updateLength()
 void KHexEdit::clipboardChanged()
 {
   // don't listen to selection changes
-  disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0 );
+  disconnect( TQApplication::clipboard(), TQ_SIGNAL(selectionChanged()), this, 0 );
   selectAll( false );
 }
 
@@ -1548,7 +1548,7 @@ void KHexEdit::contentsMousePressEvent( TQMouseEvent *e )
   pauseCursor( true );
 
   // care about a left button press?
-  if( e->button() == Qt::LeftButton )
+  if( e->button() == TQt::LeftButton )
   {
     MousePressed = true;
 
@@ -1601,7 +1601,7 @@ void KHexEdit::contentsMousePressEvent( TQMouseEvent *e )
 
     BufferRanges->removeFurtherSelections();
   }
-  else if( e->button() == Qt::MidButton )
+  else if( e->button() == TQt::MidButton )
     BufferRanges->removeSelection();
 
   if( BufferRanges->isModified() )
@@ -1674,17 +1674,17 @@ void KHexEdit::contentsMouseReleaseEvent( TQMouseEvent *e )
       if( TQApplication::clipboard()->supportsSelection() )
       {
         ClipboardMode = TQClipboard::Selection;
-        disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
+        disconnect( TQApplication::clipboard(), TQ_SIGNAL(selectionChanged()), this, 0);
 
         copy();
 
-        connect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
+        connect( TQApplication::clipboard(), TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(clipboardChanged()) );
         ClipboardMode = TQClipboard::Clipboard;
       }
     }
   }
   // middle mouse button paste?
-  else if( e->button() == Qt::MidButton && !isReadOnly() )
+  else if( e->button() == TQt::MidButton && !isReadOnly() )
   {
     pauseCursor();
 
@@ -1723,7 +1723,7 @@ void KHexEdit::contentsMouseReleaseEvent( TQMouseEvent *e )
 void KHexEdit::contentsMouseDoubleClickEvent( TQMouseEvent *e )
 {
   // we are only interested in LMB doubleclicks
-  if( e->button() != Qt::LeftButton )
+  if( e->button() != TQt::LeftButton )
   {
     e->ignore();
     return;
@@ -2008,11 +2008,11 @@ void KHexEdit::contentsContextMenuEvent( TQContextMenuEvent *e )
     if( TQApplication::clipboard()->supportsSelection() )
     {
       ClipboardMode = TQClipboard::Selection;
-      disconnect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, 0);
+      disconnect( TQApplication::clipboard(), TQ_SIGNAL(selectionChanged()), this, 0);
 
       copy();
 
-      connect( TQApplication::clipboard(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(clipboardChanged()) );
+      connect( TQApplication::clipboard(), TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(clipboardChanged()) );
       ClipboardMode = TQClipboard::Clipboard;
     }
   }
