@@ -88,12 +88,12 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
         grid->addWidget(checkCriticalPercent, curRow, 0);
         grid->addWidget(editCriticalPercent, curRow++, TQt::AlignLeft);
 
-        connect(editCriticalTime, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(configChanged()));
-        connect(editCriticalPercent, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(configChanged()));
-        connect(checkCriticalTime, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(configChanged()));
-        connect(checkCriticalPercent, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(configChanged()));
-        connect(checkCriticalTime, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(checkCriticalTimeChanged(bool)));
-        connect(checkCriticalPercent, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(checkCriticalPercentChanged(bool)));
+        connect(editCriticalTime, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(configChanged()));
+        connect(editCriticalPercent, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(configChanged()));
+        connect(checkCriticalTime, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(configChanged()));
+        connect(checkCriticalPercent, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(configChanged()));
+        connect(checkCriticalTime, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(checkCriticalTimeChanged(bool)));
+        connect(checkCriticalPercent, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(checkCriticalPercentChanged(bool)));
     } else {
         checkLowTime = new TQCheckBox( i18n("Low &trigger:"), this );
         checkLowPercent = new TQCheckBox( i18n("Low &trigger:"), this );        
@@ -108,12 +108,12 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
         grid->addWidget(checkLowPercent, curRow, 0);
         grid->addWidget(editLowPercent, curRow++, TQt::AlignLeft);
         
-        connect(editLowTime, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(configChanged()));
-        connect(editLowPercent, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(configChanged()));
-        connect(checkLowTime, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(configChanged()));
-        connect(checkLowPercent, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(configChanged()));
-        connect(checkLowTime, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(checkLowTimeChanged(bool)));
-        connect(checkLowPercent, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(checkLowPercentChanged(bool)));
+        connect(editLowTime, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(configChanged()));
+        connect(editLowPercent, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(configChanged()));
+        connect(checkLowTime, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(configChanged()));
+        connect(checkLowPercent, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(configChanged()));
+        connect(checkLowTime, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(checkLowTimeChanged(bool)));
+        connect(checkLowPercent, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(checkLowPercentChanged(bool)));
     }
 
     
@@ -123,12 +123,12 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
 
     editRunCommand = new KURLRequester( this );
     editRunCommand->setEnabled(false);
-    connect( checkRunCommand, TQT_SIGNAL(toggled(bool)),
-	     editRunCommand,  TQT_SLOT(setEnabled(bool)) );
-    connect( checkRunCommand, TQT_SIGNAL(clicked()),
-	     this, TQT_SLOT(configChanged()) );
-    connect( editRunCommand, TQT_SIGNAL(textChanged(const TQString&)),
-	     this, TQT_SLOT(configChanged()) );
+    connect( checkRunCommand, TQ_SIGNAL(toggled(bool)),
+	     editRunCommand,  TQ_SLOT(setEnabled(bool)) );
+    connect( checkRunCommand, TQ_SIGNAL(clicked()),
+	     this, TQ_SLOT(configChanged()) );
+    connect( editRunCommand, TQ_SIGNAL(textChanged(const TQString&)),
+	     this, TQ_SLOT(configChanged()) );
     grid->addWidget(editRunCommand, curRow++, 1);
     TQToolTip::add( editRunCommand, i18n( "This command will be run when the battery gets low" ) );
 
@@ -138,24 +138,24 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
 
     editPlaySound = new KURLRequester( this );
     editPlaySound->setEnabled(false);
-    connect( checkPlaySound, TQT_SIGNAL(toggled(bool)),
-	     editPlaySound,  TQT_SLOT(setEnabled(bool)) );
-    connect( checkPlaySound, TQT_SIGNAL(clicked()),
-	     this, TQT_SLOT(configChanged()) );
-    connect( editPlaySound, TQT_SIGNAL(textChanged(const TQString&)),
-	     this, TQT_SLOT(configChanged()) );
+    connect( checkPlaySound, TQ_SIGNAL(toggled(bool)),
+	     editPlaySound,  TQ_SLOT(setEnabled(bool)) );
+    connect( checkPlaySound, TQ_SIGNAL(clicked()),
+	     this, TQ_SLOT(configChanged()) );
+    connect( editPlaySound, TQ_SIGNAL(textChanged(const TQString&)),
+	     this, TQ_SLOT(configChanged()) );
     grid->addWidget(editPlaySound, curRow++, 1);
     TQToolTip::add( editPlaySound, i18n( "This sound will play when the battery gets low" ) );
 
     // setup the System Sound stuff
     checkBeep = new TQCheckBox(i18n("System &beep"), this);
     grid->addWidget(checkBeep, curRow++, 0);
-    connect(checkBeep, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+    connect(checkBeep, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     TQToolTip::add( checkBeep, i18n( "The system will beep if this is enabled" ) );
 
     checkNotify = new TQCheckBox(i18n("&Notify"), this);
     grid->addWidget(checkNotify, curRow++, 0);
-    connect(checkNotify, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+    connect(checkNotify, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
 
     int can_suspend = laptop_portable::has_suspend();
     int can_standby = laptop_portable::has_standby();
@@ -167,10 +167,10 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
       checkBrightness->setMinimumSize(checkBrightness->sizeHint());
       TQToolTip::add( checkBrightness, i18n( "If enabled the back panel brightness will change" ) );
       grid->addWidget(checkBrightness, curRow, 0);
-      connect(checkBrightness, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(brightness_changed(bool)));
+      connect(checkBrightness, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(brightness_changed(bool)));
       TQHBoxLayout *v = new TQHBoxLayout();
       v->addWidget(new TQLabel("-", this));
-      valueBrightness = new TQSlider(0, 255, 16, 160, Qt::Horizontal, this);
+      valueBrightness = new TQSlider(0, 255, 16, 160, TQt::Horizontal, this);
       TQToolTip::add( valueBrightness, i18n( "How bright or dim to make the back panel" ) );
       valueBrightness->setMaximumWidth(70);
       v->addWidget(valueBrightness);
@@ -178,7 +178,7 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
       v->addStretch(1);
       grid->addLayout(v, curRow, 1);
       valueBrightness->setEnabled(0);
-      connect(valueBrightness, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(configChanged()));
+      connect(valueBrightness, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(configChanged()));
       ++curRow;
     } else {
       checkBrightness = 0;
@@ -192,13 +192,13 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
     	performance = new TQCheckBox(i18n("System performance"), this);
         TQToolTip::add( performance, i18n( "If enabled the laptop's power performance profile will change" ) );
         grid->addWidget(performance, curRow, 0);
-    	connect (performance, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(performance_changed(bool)));
+    	connect (performance, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(performance_changed(bool)));
 
         TQHBoxLayout *v = new TQHBoxLayout();
     	performance_val = new KComboBox(0, this);
 	performance_val->insertStringList(performance_list);
     	performance_val->setEnabled(0);
-    	connect (performance_val, TQT_SIGNAL(activated(int)), this, TQT_SLOT(configChanged()));
+    	connect (performance_val, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
         TQToolTip::add( performance_val, i18n( "The performance profile to change to" ) );
 	v->addWidget(performance_val);
 	v->addStretch(1);
@@ -215,13 +215,13 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
     	throttle = new TQCheckBox(i18n("CPU throttling"), this);
         TQToolTip::add( throttle, i18n( "If enabled the CPU performance will be throttled" ) );
         grid->addWidget(throttle, curRow, 0);
-    	connect (throttle, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(throttle_changed(bool)));
+    	connect (throttle, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(throttle_changed(bool)));
 
         TQHBoxLayout *v = new TQHBoxLayout();
     	throttle_val = new KComboBox(0, this);
 	throttle_val->insertStringList(throttle_list);
     	throttle_val->setEnabled(0);
-    	connect (throttle_val, TQT_SIGNAL(activated(int)), this, TQT_SLOT(configChanged()));
+    	connect (throttle_val, TQ_SIGNAL(activated(int)), this, TQ_SLOT(configChanged()));
         TQToolTip::add( throttle_val, i18n( "How much to throttle the CPU performance by" ) );
 	v->addWidget(throttle_val);
 	v->addStretch(1);
@@ -241,30 +241,30 @@ WarningConfig::WarningConfig (int t, TQWidget * parent, const char *name)
       checkStandby = new TQRadioButton(i18n("Standb&y"), b);
       TQToolTip::add( checkStandby, i18n( "Move the system into the standby state - a temporary lower power state" ) );
       checkStandby->setMinimumSize(checkStandby->sizeHint());
-      connect(checkStandby, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+      connect(checkStandby, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     }
     if (can_suspend) {
       checkSuspend = new TQRadioButton(i18n("&Suspend"), b);
       TQToolTip::add( checkSuspend, i18n( "Move the system into the suspend state - also known as 'save-to-ram'" ) );
       checkSuspend->setMinimumSize(checkSuspend->sizeHint());
-      connect(checkSuspend, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+      connect(checkSuspend, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     }
     if (can_hibernate) {
       checkHibernate = new TQRadioButton(i18n("H&ibernate"), b);
       TQToolTip::add( checkHibernate, i18n( "Move the system into the hibernate state - also known as 'save-to-disk'" ) );
       checkHibernate->setMinimumSize(checkHibernate->sizeHint());
-      connect(checkHibernate, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+      connect(checkHibernate, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     }
     // setup the logout option
     checkLogout = new TQRadioButton(i18n("&Logout"), b);
-    connect(checkLogout, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+    connect(checkLogout, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     // setup the shutdown option
     checkShutdown = new TQRadioButton(i18n("System power off"), b);
     TQToolTip::add( checkShutdown, i18n( "Power the laptop off" ) );
-    connect(checkShutdown, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+    connect(checkShutdown, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
     
     checkNone = new TQRadioButton(i18n("&None"), b);
-    connect(checkNone, TQT_SIGNAL(clicked()), this, TQT_SLOT(configChanged()));
+    connect(checkNone, TQ_SIGNAL(clicked()), this, TQ_SLOT(configChanged()));
 
     grid->addMultiCellWidget(b, curRow, curRow, 0, 1, TQt::AlignLeft|TQt::AlignTop);
     curRow++;
