@@ -54,7 +54,7 @@ class KMiloKVaio;
  */
 class KVaio : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 //    KVaio(TQObject *parent = 0, const char *name =0);
