@@ -42,7 +42,7 @@
 using namespace KMilo;
 
 extern "C" {
-   KDE_EXPORT KDEDModule *create_kmilod(const TQCString &name) {
+   TDE_EXPORT KDEDModule *create_kmilod(const TQCString &name) {
 	   return new KMiloD(name);
    }
 }
@@ -79,7 +79,7 @@ KMiloD::KMiloD(const TQCString &name) : KDEDModule(name), _interval(100)
 	}
 
 	// Start the timer
-	TQObject::connect(&_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(doTimer()));
+	TQObject::connect(&_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(doTimer()));
 	if (shouldPoll) {
 		_timer.start(_interval);
 	}
