@@ -149,13 +149,13 @@ PyObject* py_execute_command_interactive(PyObject *, PyObject* args)
 
   }
   TQApplication::connect(currTheme->currProcess,
-                        TQT_SIGNAL(processExited(TDEProcess *)),
+                        TQ_SIGNAL(processExited(TDEProcess *)),
                         currTheme,
-                        TQT_SLOT(processExited(TDEProcess *)));
+                        TQ_SLOT(processExited(TDEProcess *)));
   TQApplication::connect(currTheme->currProcess,
-                        TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+                        TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
                         currTheme,
-                        TQT_SLOT(receivedStdout(TDEProcess *, char *, int)));
+                        TQ_SLOT(receivedStdout(TDEProcess *, char *, int)));
   currTheme->currProcess->start(TDEProcess::NotifyOnExit, TDEProcess::Stdout);
 
   return Py_BuildValue((char*)"l", (int)(currTheme->currProcess->pid()));
