@@ -40,7 +40,7 @@
 #include "sknewstuff.h"
 
 SKNewStuff::SKNewStuff( ThemesDlg *dlg ) :
-  TDENewStuff( "superkaramba/themes", dlg ),
+  TDENewStuff( "Karamba & Superkaramba", dlg ),
   mDlg( dlg )
 {
 }
