@@ -34,8 +34,8 @@
 
 AddAction::AddAction(TQWidget *parent, const char *name, const Mode &mode): AddActionBase(parent, name), theMode(mode)
 {
-	connect(this, TQT_SIGNAL( selected(const TQString &) ), TQT_SLOT( updateForPageChange() ));
-	connect(this, TQT_SIGNAL( selected(const TQString &) ), TQT_SLOT( slotCorrectPage() ));
+	connect(this, TQ_SIGNAL( selected(const TQString &) ), TQ_SLOT( updateForPageChange() ));
+	connect(this, TQ_SIGNAL( selected(const TQString &) ), TQ_SLOT( slotCorrectPage() ));
 	curPage = 0;
 	updateProfiles();
 	updateButtons();
