@@ -66,7 +66,7 @@ TDEWalletEditor::TDEWalletEditor(const TQString& wallet, bool isPath, TQWidget *
 : TDEMainWindow(parent, name), _walletName(wallet), _nonLocal(isPath) {
 	_newWallet = false;
 	_ww = new WalletWidget(this, "Wallet Widget");
-	_copyPassAction = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(copyPassword()), actionCollection());
+	_copyPassAction = KStdAction::copy(this, TQ_SLOT(copyPassword()), actionCollection());
 
 	TQVBoxLayout *box = new TQVBoxLayout(_ww->_entryListFrame);
 	box->setSpacing( KDialog::spacingHint() );
@@ -79,7 +79,7 @@ TDEWalletEditor::TDEWalletEditor(const TQString& wallet, bool isPath, TQWidget *
 
 	box = new TQVBoxLayout(_ww->_entryStack->widget(2));
 	_mapEditorShowHide = new TQCheckBox(i18n("&Show values"), _ww->_entryStack->widget(2));
-	connect(_mapEditorShowHide, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(showHideMapEditorValue(bool)));
+	connect(_mapEditorShowHide, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(showHideMapEditorValue(bool)));
 	_mapEditor = new KWMapEditor(_currentMap, _ww->_entryStack->widget(2));
 	box->addWidget(_mapEditorShowHide);
 	box->addWidget(_mapEditor);
@@ -88,40 +88,40 @@ TDEWalletEditor::TDEWalletEditor(const TQString& wallet, bool isPath, TQWidget *
 
 	resize(600, 400);
 
-	connect(_entryList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-		this, TQT_SLOT(entrySelectionChanged(TQListViewItem*)));
+	connect(_entryList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+		this, TQ_SLOT(entrySelectionChanged(TQListViewItem*)));
 	connect(_entryList,
-		TQT_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)),
+		TQ_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)),
 		this,
-		TQT_SLOT(listContextMenuRequested(TQListViewItem*,const TQPoint&,int)));
+		TQ_SLOT(listContextMenuRequested(TQListViewItem*,const TQPoint&,int)));
 	connect(_entryList,
-		TQT_SIGNAL(itemRenamed(TQListViewItem*, int, const TQString&)),
+		TQ_SIGNAL(itemRenamed(TQListViewItem*, int, const TQString&)),
 		this,
-		TQT_SLOT(listItemRenamed(TQListViewItem*, int, const TQString&)));
+		TQ_SLOT(listItemRenamed(TQListViewItem*, int, const TQString&)));
 
-	connect(_ww->_passwordValue, TQT_SIGNAL(textChanged()),
-		this, TQT_SLOT(entryEditted()));
-	connect(_mapEditor, TQT_SIGNAL(dirty()),
-		this, TQT_SLOT(entryEditted()));
+	connect(_ww->_passwordValue, TQ_SIGNAL(textChanged()),
+		this, TQ_SLOT(entryEditted()));
+	connect(_mapEditor, TQ_SIGNAL(dirty()),
+		this, TQ_SLOT(entryEditted()));
 
-	connect(_ww->_undoChanges, TQT_SIGNAL(clicked()),
-		this, TQT_SLOT(restoreEntry()));
-	connect(_ww->_saveChanges, TQT_SIGNAL(clicked()),
-		this, TQT_SLOT(saveEntry()));
+	connect(_ww->_undoChanges, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(restoreEntry()));
+	connect(_ww->_saveChanges, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(saveEntry()));
 
-	connect(_ww->_showContents, TQT_SIGNAL(clicked()),
-		this, TQT_SLOT(showPasswordContents()));
-	connect(_ww->_hideContents, TQT_SIGNAL(clicked()),
-		this, TQT_SLOT(hidePasswordContents()));
+	connect(_ww->_showContents, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(showPasswordContents()));
+	connect(_ww->_hideContents, TQ_SIGNAL(clicked()),
+		this, TQ_SLOT(hidePasswordContents()));
 
 	_walletIsOpen = false;
 
 	_w = TDEWallet::Wallet::openWallet(wallet, winId(), isPath ? TDEWallet::Wallet::Path : TDEWallet::Wallet::Asynchronous);
 	if (_w) {
-		connect(_w, TQT_SIGNAL(walletOpened(bool)), this, TQT_SLOT(walletOpened(bool)));
-		connect(_w, TQT_SIGNAL(walletClosed()), this, TQT_SLOT(walletClosed()));
-		connect(_w, TQT_SIGNAL(folderUpdated(const TQString&)), this, TQT_SLOT(updateEntries(const TQString&)));
-		connect(_w, TQT_SIGNAL(folderListUpdated()), this, TQT_SLOT(updateFolderList()));
+		connect(_w, TQ_SIGNAL(walletOpened(bool)), this, TQ_SLOT(walletOpened(bool)));
+		connect(_w, TQ_SIGNAL(walletClosed()), this, TQ_SLOT(walletClosed()));
+		connect(_w, TQ_SIGNAL(folderUpdated(const TQString&)), this, TQ_SLOT(updateEntries(const TQString&)));
+		connect(_w, TQ_SIGNAL(folderListUpdated()), this, TQ_SLOT(updateFolderList()));
 		updateFolderList();
 	} else {
 		kdDebug(2300) << "Wallet open failed!" << endl;
@@ -133,7 +133,7 @@ TDEWalletEditor::TDEWalletEditor(const TQString& wallet, bool isPath, TQWidget *
 
 	setCaption(wallet);
 
-	TQTimer::singleShot(0, this, TQT_SLOT(layout()));
+	TQTimer::singleShot(0, this, TQ_SLOT(layout()));
 }
 
 TDEWalletEditor::~TDEWalletEditor() {
@@ -159,49 +159,49 @@ void TDEWalletEditor::layout() {
 
 void TDEWalletEditor::createActions() {
 	_newFolderAction = new TDEAction(i18n("&New Folder..."), "folder-new",
-			0, TQT_TQOBJECT(this), TQT_SLOT(createFolder()), actionCollection(),
+			0, this, TQ_SLOT(createFolder()), actionCollection(),
 			"create_folder");
-	connect(this, TQT_SIGNAL(enableFolderActions(bool)),
-		_newFolderAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableFolderActions(bool)),
+		_newFolderAction, TQ_SLOT(setEnabled(bool)));
 
 	_deleteFolderAction = new TDEAction(i18n("&Delete Folder"), 0, 0,
-			TQT_TQOBJECT(this), TQT_SLOT(deleteFolder()), actionCollection(),
+			this, TQ_SLOT(deleteFolder()), actionCollection(),
 			"delete_folder");
-	connect(this, TQT_SIGNAL(enableContextFolderActions(bool)),
-		_deleteFolderAction, TQT_SLOT(setEnabled(bool)));
-	connect(this, TQT_SIGNAL(enableFolderActions(bool)),
-		_deleteFolderAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableContextFolderActions(bool)),
+		_deleteFolderAction, TQ_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableFolderActions(bool)),
+		_deleteFolderAction, TQ_SLOT(setEnabled(bool)));
 
-	_passwordAction = new TDEAction(i18n("Change &Password..."), 0, 0, TQT_TQOBJECT(this),
-			TQT_SLOT(changePassword()), actionCollection(),
+	_passwordAction = new TDEAction(i18n("Change &Password..."), 0, 0, this,
+			TQ_SLOT(changePassword()), actionCollection(),
 			"change_password");
-	connect(this, TQT_SIGNAL(enableWalletActions(bool)),
-		_passwordAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableWalletActions(bool)),
+		_passwordAction, TQ_SLOT(setEnabled(bool)));
 
-	_mergeAction = new TDEAction(i18n("&Merge Wallet..."), 0, 0, TQT_TQOBJECT(this),
-			TQT_SLOT(importWallet()), actionCollection(),
+	_mergeAction = new TDEAction(i18n("&Merge Wallet..."), 0, 0, this,
+			TQ_SLOT(importWallet()), actionCollection(),
 			"merge");
-	connect(this, TQT_SIGNAL(enableWalletActions(bool)),
-		_mergeAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableWalletActions(bool)),
+		_mergeAction, TQ_SLOT(setEnabled(bool)));
 
-	_importAction = new TDEAction(i18n("&Import XML..."), 0, 0, TQT_TQOBJECT(this),
-			TQT_SLOT(importXML()), actionCollection(),
+	_importAction = new TDEAction(i18n("&Import XML..."), 0, 0, this,
+			TQ_SLOT(importXML()), actionCollection(),
 			"import");
-	connect(this, TQT_SIGNAL(enableWalletActions(bool)),
-		_importAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableWalletActions(bool)),
+		_importAction, TQ_SLOT(setEnabled(bool)));
 
-	_exportAction = new TDEAction(i18n("&Export..."), 0, 0, TQT_TQOBJECT(this),
-			TQT_SLOT(exportXML()), actionCollection(),
+	_exportAction = new TDEAction(i18n("&Export..."), 0, 0, this,
+			TQ_SLOT(exportXML()), actionCollection(),
 			"export");
-	connect(this, TQT_SIGNAL(enableWalletActions(bool)),
-		_exportAction, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(enableWalletActions(bool)),
+		_exportAction, TQ_SLOT(setEnabled(bool)));
 
-	_saveAsAction = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
-	connect(this, TQT_SIGNAL(enableWalletActions(bool)),
-		_saveAsAction, TQT_SLOT(setEnabled(bool)));
+	_saveAsAction = KStdAction::saveAs(this, TQ_SLOT(saveAs()), actionCollection());
+	connect(this, TQ_SIGNAL(enableWalletActions(bool)),
+		_saveAsAction, TQ_SLOT(setEnabled(bool)));
 
-	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	KStdAction::keyBindings(guiFactory(), TQT_SLOT(configureShortcuts()),
+	KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
+	KStdAction::keyBindings(guiFactory(), TQ_SLOT(configureShortcuts()),
 actionCollection());
 	emit enableWalletActions(false);
 	emit enableFolderActions(false);
@@ -585,9 +585,9 @@ void TDEWalletEditor::listContextMenuRequested(TQListViewItem *item, const TQPoi
 		m->insertTitle(title);
 		switch (menuClass) {
 			case TDEWalletEntryItemClass:
-				m->insertItem(i18n("&New..." ), this, TQT_SLOT(newEntry()), Key_Insert);
-				m->insertItem(i18n( "&Rename" ), this, TQT_SLOT(renameEntry()), Key_F2);
-				m->insertItem(i18n( "&Delete" ), this, TQT_SLOT(deleteEntry()), Key_Delete);
+				m->insertItem(i18n("&New..." ), this, TQ_SLOT(newEntry()), Key_Insert);
+				m->insertItem(i18n( "&Rename" ), this, TQ_SLOT(renameEntry()), Key_F2);
+				m->insertItem(i18n( "&Delete" ), this, TQ_SLOT(deleteEntry()), Key_Delete);
 				if (ci && ci->type() == TDEWallet::Wallet::Password) {
 					m->insertSeparator();
 					_copyPassAction->plug(m);
@@ -595,7 +595,7 @@ void TDEWalletEditor::listContextMenuRequested(TQListViewItem *item, const TQPoi
 				break;
 
 			case TDEWalletContainerItemClass:
-				m->insertItem(i18n( "&New..." ), this, TQT_SLOT(newEntry()), Key_Insert);
+				m->insertItem(i18n( "&New..." ), this, TQ_SLOT(newEntry()), Key_Insert);
 				break;
 
 			case TDEWalletFolderItemClass:
